package
module
Version:
v0.0.0-...-3bbe4be
Opens a new window with list of versions in this module.
Published: Jul 26, 2024
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
type OptFunc func(*Props)
type Props struct {
Width string `json:"width,omitempty"`
Height string `json:"height,omitempty"`
Class string `json:"class,omitempty"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.